-------------------------------------------------------------------------------
-- MrTrader 
--
-- Suite of tools for the avid crafter.
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

MRTProfit = LibStub("AceAddon-3.0"):NewAddon("MrTrader_Profit",
											 "AceBucket-3.0",
											 "AceEvent-3.0");											

local L = LibStub("AceLocale-3.0"):GetLocale("MrTrader", true);

-----
-- SkillWindow_InfoLine Interface
--
-- Function: SkillWindow_InfoLine
-- Arguments: 
--		tradeskillInfo - An object that represents the tradeskill info.
-----
function MRTProfit:SkillWindow_InfoLine(tradeskillInfo)
	if( tradeskillInfo.altVerb ~= nil ) then
	    return nil;
	end
	
	if( tradeskillInfo.itemLink == nil ) then
		return nil;
	end
	
	local salePrice = MRTProfit:GetBestSalePrice(tradeskillInfo);
	local profit = salePrice - MRTProfit:GetPurchasePrice(tradeskillInfo);
	local result = "";
	
	-- No way to sell it (no vendor, no disenchant, no auction)... don't bother polluting the list with it.
	if( salePrice == 0 ) then
		return nil;
	end
	-- Only vendors, and isn't a profit... don't list it. We only care about the loss on tradable items, or the profit on vendorable items
	if( salePrice == tradeskillInfo.itemSellPrice and profit < 0 ) then
		return nil;
	end
	
	if( profit >= 0 ) then
		result = "|cff00aa00Profit:|r ";
	else
	    result = "|cffaa0000Loss:|r ";
		profit = -profit;
	end
	
	result = result .. GetCoinTextureString(profit);
	
	return result;
end

-----
-- Functions
-----
function MRTProfit:OnInitialize()
	print("MrTrader: Profit Loaded")
    -- Add ourselves to MrTrader plugins
	self.interfaces = { "SkillWindow_InfoLine", "SkillWindow_TooltipInfo" };
	self.name = L["Profit Estimate"];
	self.id = "MRTrader_Profit";
	
	MRTUIUtils_RegisterPlugin(self);
end

-- price = AuctionLite:GetDisenchantValue(link or id[, suffix])
-- price = AuctionLite:GetAuctionValue(link or id[, suffix])

function MRTProfit:GetAuctionPrice(itemLink)
	if( AuctionLite ~= nil ) then
		return AuctionLite:GetAuctionValue(itemLink) or 0;
	end

	return 0;
end

function MRTProfit:GetDisenchantPrice(itemLink)	
	if( AuctionLite ~= nil ) then
		return AuctionLite:GetDisenchantValue(itemLink) or 0;
	end
		
	return 0;
end

function MRTProfit:GetBestSalePrice(tradeskillInfo)
	local availablePrices = {};
	local bestPrice = 0;
	local averageMade = tradeskillInfo.minMade + ((tradeskillInfo.maxMade - tradeskillInfo.minMade) / 2);
	
	if( tradeskillInfo.itemSellPrice ~= nil ) then
		tinsert(availablePrices, tradeskillInfo.itemSellPrice);
	end
	
	tinsert(availablePrices, MRTProfit:GetDisenchantPrice(tradeskillInfo.itemLink));
	tinsert(availablePrices, MRTProfit:GetAuctionPrice(tradeskillInfo.itemLink));
	
	local count = getn(availablePrices);
	for i=1, count do
		if( availablePrices[i] > bestPrice ) then
			bestPrice = availablePrices[i];
		end
	end
	
	return bestPrice * averageMade
end

function MRTProfit:GetPurchasePrice(tradeskillInfo)
	local purchasePrice = 0;
	
	local count = getn(tradeskillInfo.reagents);
	for i=1,count do
		purchasePrice = purchasePrice + (MRTProfit:GetAuctionPrice(tradeskillInfo.reagents[i].itemLink) * tradeskillInfo.reagents[i].count);
	end
	
	return purchasePrice;
end




